@@ -68,7 +68,7 @@
 #'   info <- getInfo(fileName = file_cif, from = "analysis")
 #'   ## randomly show at most 10 "img" objects from file
 #'   DisplayGallery(info = info, image_type = "img", extract_max = 10,
-#'                  sampling = TRUE, write_to = "example.png")
+#'                  sampling = TRUE, write_to = "example.bmp")
 #' } else {
 #'   message(sprintf('Please run `install.packages("IFCdata", repos = "%s", type = "source")` %s',
 #'                   'https://gitdemont.github.io/IFCdata/',
@@ -195,7 +195,7 @@ DisplayGallery <- function(...,
                                     force_width = force_width), dots_param))
     } else {
       param = do.call(what = "objectParam",
-                      args = c(list(info = input$info,
+                      args = c(list(info = quote(input$info),
                                     export = "base64",
                                     mode = mode,
                                     size = size, 
