@@ -32,19 +32,18 @@
 #' This function is intended to display object extracted by \code{\link{objectExtract}}.
 #' @param image An object extracted by \code{\link{objectExtract}} of class `IFC_img` or `IFC_msk`.\cr
 #' Note that a matrix with finite values can also be used.
-#' @param input_range a finite numeric vector of 2 values, sets the range of the input intensity values.\cr
-#' Values exceeding this range are clipped. Default is 'c(0, 4095)'.
-#' @param full_range if 'full_range' is TRUE, then 'input_range' will be set to 'c(0, 4095)' and 'gamma' forced to 1. Default is FALSE.
-#' @param force_range if 'force_range' is TRUE, then 'input_range' will be adjusted to object range in [-4095, +inf] and 'gamma' forced to 1. Default is FALSE.\cr
-#' Note that this parameter takes the precedence over 'input_range' and 'full_range'.
-#' @param gamma gamma correction. Default is 1, for no correction.
-#' @param color a color. Default is "Green".
-#' @details If input 'image' is of class `IFC_img` or `IFC_msk`, then if 'input_range', 'full_range', 'force_range', 'gamma' and / or 'color' parameters is/are missing,
-#' it/they will be extracted from 'image' attributes.\cr
-#' If input 'image' is not of one of class `IFC_img` or `IFC_msk`, then force_range will be forced to TRUE.\cr
+#' @param input_range a finite numeric vector of 2 values, sets the range of the input intensity values. Values outside this range are clipped. Default is \code{[0,4095]}.
+#' @param full_range if \code{'full_range'} is \code{TRUE}, then \code{'input_range'} will be set to \code{[0,4095]} and \code{'gamma'} forced to \code{1}. Default is \code{FALSE}.
+#' @param force_range if \code{'force_range'} is \code{TRUE}, then \code{'input_range'} will be adjusted to \code{'image'} range in \code{[-4095,+inf]} and \code{'gamma'} forced to \code{1}. Default is \code{FALSE}.\cr
+#' Note that this parameter takes the precedence over \code{input_range}' and \code{full_range}'.
+#' @param gamma \code{'gamma'} correction. Default is \code{1}, for no correction.
+#' @param color a color. Default is \code{"Green"}.
+#' @details If \code{'image'} is of class `IFC_img` or `IFC_msk`, then if \code{'input_range'}, \code{'full_range'}, \code{'force_range'}, \code{'gamma'} and/or \code{'color'} parameters is/are missing,
+#' it/they will be extracted from \code{'image'} attributes.\cr
+#' If \code{'image'} is not of one of class `IFC_img` or `IFC_msk`, then \code{'force_range'} will be forced to \code{TRUE}.\cr
 #' An error will be thrown if input image contains non finite values.
-#' @param dpi display resolution. Default is 300.
-#' @return it invisibly returns NULL
+#' @param dpi display resolution. Default is \code{300}.
+#' @return it invisibly returns \code{NULL}
 #' @export
 objectDisplay = function(image, input_range = c(0, 4095), full_range = FALSE, force_range = FALSE, gamma = 1, color = "Green", dpi = 300) {
   dpi = na.omit(as.integer(dpi)); dpi = dpi[dpi>0]; dpi = dpi[is.finite(dpi)]
@@ -60,7 +59,11 @@ objectDisplay = function(image, input_range = c(0, 4095), full_range = FALSE, fo
     if(missing(color)) color = attr(image, "color")
     checkColor(color)
     if("IFC_img" %in% K) {
-      foo = objectColorize(objectNormalize(attr(image, "raw"), input_range = input_range, full_range = full_range, force_range = force_range, gamma = gamma), color)
+      if(inherits(input_range, "quantile") && identical(gamma, attr(image, "gamma"))) {
+        foo = objectColorize(objectNormalize(attr(image, "raw"), input_range = input_range, full_range = full_range, force_range = force_range, gamma = 1), color) 
+      } else {
+        foo = objectColorize(objectNormalize(attr(image, "raw"), input_range = input_range, full_range = full_range, force_range = force_range, gamma = gamma), color)
+      }
     } else {
       foo = objectColorize(objectNormalize(attr(image, "raw"), input_range = input_range, full_range = full_range, force_range = force_range, gamma = 1), color)
     }
